@@ -1,13 +1,9 @@
 import csv
 import io
-from collections import OrderedDict
-
 import pytz
-from django import forms
-from django.db.models.functions import Coalesce
 from django.utils.translation import gettext as _, gettext_lazy
 from pretix.base.exporter import BaseExporter
-from pretix.base.models import Order, OrderPosition, Question
+
 from pretix_sepadebit.models import SepaExportOrder
 
 
